@@ -57,7 +57,8 @@ class QuerySet(Publishable):
         queryset = model.objects.filter(
             published=True,
             date_available__lte=timezone.now(),
-            site=self.site)
+            site=self.site
+        ).exclude(child_class='Mirror')
 
         try:
             if model._meta.get_field_by_name('show_on_root_channel'):
