@@ -1,6 +1,5 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-
 import operator
 
 from django.db import models
@@ -15,13 +14,15 @@ from django.template.defaultfilters import slugify
 from polymorphic import PolymorphicModel
 from polymorphic.showfields import ShowFieldContent
 
-from .signals import shorturl_generate, delete_container
 from opps.core.cache import _cache_key
 from opps.core.models import Publishable, Slugged, Channeling, Imaged
 from opps.core.tags.models import Tagged
 from opps.db.models.fields import JSONField
 from opps.boxes.models import BaseBox
 
+from .signals import shorturl_generate, delete_container
+from .tasks import check_mirror_channel
+
 
 class Container(PolymorphicModel, ShowFieldContent, Publishable, Slugged,
                 Channeling, Imaged, Tagged):
@@ -82,8 +83,10 @@ class Container(PolymorphicModel, ShowFieldContent, Publishable, Slugged,
         unique_together = ("site", "channel_long_slug", "slug")
 
     def save(self, *args, **kwargs):
-        self.channel_name = self.channel.name
-        self.channel_long_slug = self.channel.long_slug
+        if not self.channel_name:
+            self.channel_name = self.channel.name
+        if not self.channel_long_slug:
+            self.channel_long_slug = self.channel.long_slug
         self.child_class = self.__class__.__name__
         self.child_module = self.__class__.__module__
         self.child_app_label = self._meta.app_label
@@ -93,6 +96,9 @@ class Container(PolymorphicModel, ShowFieldContent, Publishable, Slugged,
         models.signals.post_save.connect(shorturl_generate,
                                          sender=self.__class__)
         super(Container, self).save(*args, **kwargs)
+        if settings.OPPS_MIRROR_CHANNEL and self.mirror_channel:
+            check_mirror_channel.delay(
+                container=self, Mirror=Mirror)
 
     def get_absolute_url(self):
         return u"/{}/{}.html".format(self.channel_long_slug, self.slug)
@@ -205,6 +211,12 @@ class ContainerBox(BaseBox):
         blank=True,
         max_length=140,
     )
+    title_url = models.CharField(
+        _(u"Title Link"),
+        null=True,
+        blank=True,
+        max_length=250,
+    )
     containers = models.ManyToManyField(
         'containers.Container',
         null=True, blank=True,
@@ -316,4 +328,10 @@ class ContainerBoxContainers(models.Model):
             raise ValidationError(_(u'Article not published!'))
 
 
+class Mirror(Container):
+    container = models.ForeignKey('containers.Container',
+                                  related_name='containers_mirror',
+                                  verbose_name=_(u'Container'))
+
+
 models.signals.post_delete.connect(delete_container, sender=Container)
