@@ -8,7 +8,6 @@ from opps.core.tags.views import TagList
 from opps.core.cache import cache_page
 
 from .views import ContainerList, ContainerDetail
-from .views import ContainerAPIList, ContainerAPIDetail
 from .views import Search
 
 
@@ -29,16 +28,10 @@ urlpatterns = patterns(
         cache_page(settings.OPPS_CACHE_EXPIRE)(
             ChannelFeed()), name='channel_feed'),
 
-    url(r'^(?P<channel__long_slug>[\w//-]+)/(?P<slug>[\w-]+).api$',
-        cache_page(settings.OPPS_CACHE_EXPIRE_DETAIL)(
-            ContainerAPIDetail.as_view()), name='open-api'),
     url(r'^(?P<channel__long_slug>[\w//-]+)/(?P<slug>[\w-]+)\.html$',
         cache_page(settings.OPPS_CACHE_EXPIRE_DETAIL)(
             ContainerDetail.as_view()), name='open'),
 
-    url(r'^(?P<channel__long_slug>[\w\b//-]+).api$',
-        cache_page(settings.OPPS_CACHE_EXPIRE_LIST)(
-            ContainerAPIList.as_view()), name='channel-api'),
     url(r'^(?P<channel__long_slug>[\w\b//-]+)/$',
         cache_page(settings.OPPS_CACHE_EXPIRE_LIST)(
             ContainerList.as_view()), name='channel'),
