@@ -105,9 +105,11 @@ class MobileDetectionMiddleware(object):
             if settings.OPPS_DOMAIN_MOBILE and \
                request.META.get('HTTP_HOST', '') != \
                settings.OPPS_DOMAIN_MOBILE:
-                return HttpResponseRedirect(u"{}://{}".format(
+                return HttpResponseRedirect(u"{}://{}{}".format(
                     settings.OPPS_PROTOCOL_MOBILE,
-                    settings.OPPS_DOMAIN_MOBILE))
+                    settings.OPPS_DOMAIN_MOBILE,
+                    request.path
+                ))
 
 
 class MobileRedirectMiddleware(object):
