@@ -81,10 +81,17 @@ class NotUserPublishable(Publisher):
 
 
 class Channeling(models.Model):
+
     channel = models.ForeignKey(
         'channels.Channel',
         verbose_name=_(u"Channel"),
     )
+    mirror_channel = models.ManyToManyField(
+        'channels.Channel',
+        related_name="%(app_label)s_%(class)s_mirror_channel",
+        null=True, blank=True,
+        verbose_name=_(u"Mirror channel"),
+    )
     channel_name = models.CharField(
         _(u"Channel name"),
         max_length=140,
