@@ -6,7 +6,7 @@ from django.contrib.auth import get_user_model
 from django.contrib.sites.models import Site
 from django.conf import settings
 
-from redactor.widgets import RedactorEditor
+from opps.core.widgets import OppsEditor
 
 from .models import FlatPage
 from opps.core.admin import apply_opps_rules
@@ -16,7 +16,7 @@ from opps.images.generate import image_url
 class FlatPageAdminForm(forms.ModelForm):
     class Meta:
         model = FlatPage
-        widgets = {'content': RedactorEditor()}
+        widgets = {'content': OppsEditor()}
 
 
 @apply_opps_rules('flatpages')
@@ -41,7 +41,7 @@ class FlatPageAdmin(admin.ModelAdmin):
     def image_thumb(self, obj):
         if obj.main_image:
             return u'<img width="60px" height="60px" src="{0}" />'.format(
-                image_url(obj.main_image.image.url, width=60, height=60))
+                image_url(obj.main_image.archive.url, width=60, height=60))
         return _(u'No Image')
     image_thumb.short_description = _(u'Thumbnail')
     image_thumb.allow_tags = True
