@@ -20,10 +20,10 @@ urlpatterns = patterns(
     url(r'^\.xml$', cache_page(86400)(sitemap_views.index),
         {'sitemaps': sitemaps, 'sitemap_url_name': 'sitemaps'},),
     url(r'^-googlenews\.xml$',
-        'opps.sitemaps.views.sitemap',
+        cache_page(86400)(sitemap_views.sitemap),
         {'sitemaps': sitemaps_googlenews,
          'template_name': 'sitemap_googlenews.xml'}),
     url(r'^-(?P<section>.+)\.xml$',
-        'opps.sitemaps.views.sitemap',
+        cache_page(86400)(sitemap_views.sitemap),
         {'sitemaps': sitemaps}, name='sitemaps'),
 )
