@@ -2,13 +2,11 @@
 # -*- coding: utf-8 -*-
 from django.conf.urls import patterns, url, include
 from django.contrib import admin
-from filebrowser.sites import site
 
 admin.autodiscover()
 
 urlpatterns = patterns(
     '',
-    url(r'^admin/filebrowser/', include(site.urls)),
     url(r'^admin/images/', include('opps.images.urls')),
     url(r'^grappelli/', include('grappelli.urls')),
 
@@ -18,7 +16,8 @@ urlpatterns = patterns(
 
     url(r'^sitemap', include('opps.sitemaps.urls')),
 
-    url(r'^api/', include('opps.api.urls')),
+    url(r'^api/', include('opps.api.urls', namespace='api',
+                          app_name='api')),
 
     url(r'^', include('opps.flatpages.urls', namespace='flatpages',
                       app_name='flatpages')),
